package Catmandu::Inspire;

our $VERSION = 'v0.24';

1;
__END__

=head1 NAME

Catmandu::Inspire - Catmandu modules for working with Inspire data.

=head1 MODULES

=over

=item * L<Catmandu::Importer::Inspire>

=item * L<Catmandu::Fix::inspire_extract_id>

=back

=head1 AUTHOR

=over

=item * Vitali Peil, C<< <vitali.peil at uni-bielefeld.de> >>

=back

=cut
